@@ -15,6 +15,10 @@ class AbstractApplication(ABC):
         self.service.create (object)
 
     def ___retrive_by_external_id_and_seon_entity_name (self, external_id, seon_entity_name):
+
+        if isinstance(external_id, int):
+            external_id = str(external_id)
+
         return self.service.session.query(ApplicationReference).filter(ApplicationReference.external_id == external_id, 
                                                                ApplicationReference.entity_name == seon_entity_name).first()
 
@@ -30,6 +34,9 @@ class AbstractApplication(ABC):
         return None
 
     def retrive_by_external_uuid(self, external_uuid):
+        
+        if isinstance(external_uuid, int):
+            external_uuid = str(external_uuid)
 
         application_reference = self.___retrive_by_external_id_and_seon_entity_name(external_uuid, self.service.type)
         if application_reference:
